"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DropdownMenuButton = void 0;
const react_1 = __importStar(require("react"));
const emotion_1 = require("@leafygreen-ui/emotion");
const leafygreen_1 = require("../leafygreen");
const workspace_container_1 = require("../workspace-container");
const constants_1 = require("./constants");
const utils_1 = require("./utils");
const action_glyph_1 = require("./action-glyph");
const item_action_menu_1 = require("./item-action-menu");
const hiddenOnNarrowStyles = (0, emotion_1.css)({
    [`@container ${workspace_container_1.WorkspaceContainer.toolbarContainerQueryName} (width < 900px)`]: {
        display: 'none',
    },
});
function DropdownMenuButton({ isVisible = true, actions, onAction, renderMode, activeAction, buttonText, buttonProps, iconSize = constants_1.ItemActionButtonSize.Default, 'data-testid': dataTestId, hideOnNarrow = true, }) {
    // this ref is used by the Menu component to calculate the height and position
    // of the menu, and by us to give back the focus to the trigger when the menu
    // is closed (https://jira.mongodb.org/browse/PD-1674).
    const menuTriggerRef = (0, react_1.useRef)(null);
    const [isMenuOpen, setIsMenuOpen] = (0, react_1.useState)(false);
    const onClick = (0, react_1.useCallback)((evt) => {
        evt.stopPropagation();
        if (evt.currentTarget.dataset.menuitem) {
            setIsMenuOpen(false);
            // Workaround for https://jira.mongodb.org/browse/PD-1674
            menuTriggerRef.current?.focus();
        }
        const actionName = evt.currentTarget.dataset.action;
        if (typeof actionName !== 'string') {
            throw new Error('Expected element to have a "data-action" attribute');
        }
        onAction(actionName);
    }, [onAction]);
    const shouldRender = isMenuOpen || (isVisible && actions.length > 0);
    if (!shouldRender) {
        return null;
    }
    return (react_1.default.createElement(leafygreen_1.Menu, { open: isMenuOpen, setOpen: setIsMenuOpen, justify: "start", refEl: menuTriggerRef, renderMode: renderMode, "data-testid": dataTestId, trigger: ({ onClick, children, }) => {
            return (react_1.default.createElement(leafygreen_1.Button, { ref: menuTriggerRef, "data-testid": dataTestId ? `${dataTestId}-show-actions` : undefined, onClick: (evt) => {
                    evt.stopPropagation();
                    onClick && onClick(evt);
                }, rightGlyph: react_1.default.createElement(leafygreen_1.Icon, { glyph: 'CaretDown' }), title: buttonText, ...buttonProps },
                buttonText && (react_1.default.createElement("span", { className: hideOnNarrow ? hiddenOnNarrowStyles : undefined }, buttonText)),
                children));
        } }, actions.map((menuAction, idx) => {
        if ((0, item_action_menu_1.isSeparatorMenuAction)(menuAction)) {
            return react_1.default.createElement(leafygreen_1.MenuSeparator, { key: `separator-${idx}` });
        }
        const { action, label, icon } = menuAction;
        return (react_1.default.createElement(leafygreen_1.MenuItem, { active: activeAction === action, key: action, "data-testid": (0, utils_1.actionTestId)(dataTestId, action), "data-action": action, "data-menuitem": true, glyph: icon ? react_1.default.createElement(action_glyph_1.ActionGlyph, { glyph: icon, size: iconSize }) : undefined, onClick: onClick }, label));
    })));
}
exports.DropdownMenuButton = DropdownMenuButton;
//# sourceMappingURL=dropdown-menu-button.js.map